"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const unibeautify_1 = require("unibeautify");
const path = require("path");
const findGlobalPackages = require("find-global-packages");
const requireg = require("requireg");
/**
Find all globally installed beautifiers.
*/
function findInstalledBeautifiers() {
    return new Promise((resolve, reject) => {
        findGlobalPackages((err, globalPackageDirs) => {
            if (err) {
                return reject(err);
            }
            const packageNames = globalPackageDirs.map((dir) => path.basename(dir));
            const beautifierNames = packageNames.filter((name) => {
                return /beautifier-.*/.test(name);
            });
            return resolve(beautifierNames);
        });
    });
}
exports.findInstalledBeautifiers = findInstalledBeautifiers;
function loadBeautifiers(beautifierNames) {
    const beautifiers = beautifierNames.map((beautifierName) => {
        return requireg(beautifierName);
    });
    return unibeautify_1.default.loadBeautifiers(beautifiers);
}
exports.loadBeautifiers = loadBeautifiers;
function loadInstalledBeautifiers() {
    return findInstalledBeautifiers()
        .then((beautifierNames) => {
        return loadBeautifiers(beautifierNames);
    });
}
exports.loadInstalledBeautifiers = loadInstalledBeautifiers;
function setupUnibeautify() {
    return loadInstalledBeautifiers();
}
exports.setupUnibeautify = setupUnibeautify;
//# sourceMappingURL=index.js.map